HighlightTweakValue

Enum HighlightTweakValue 

pub enum HighlightTweakValue {
    Yes,
    No,
}
Whether or not a message should be highlighted in the UI.

This will normally take the form of presenting the message in a different color and/or style. The UI might also be adjusted to draw particular attention to the room in which the event occurred.

Variants



Yes

Highlight the message.



No

Don’t highlight the message.