PushCondition

Enum PushCondition 

#[non_exhaustive]
pub enum PushCondition { EventMatch(EventMatchConditionData), ContainsDisplayName, RoomMemberCount(RoomMemberCountConditionData), SenderNotificationPermission(SenderNotificationPermissionConditionData), RoomVersionSupports(RoomVersionSupportsConditionData), EventPropertyIs(EventPropertyIsConditionData), EventPropertyContains(EventPropertyContainsConditionData), ThreadSubscription(ThreadSubscriptionConditionData), }
A condition that must apply for an associated push rule’s action to be taken.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


EventMatch(EventMatchConditionData)

A glob pattern match on a field of the event.



ContainsDisplayName

👎Deprecated

Matches unencrypted messages where content.body contains the owner’s display name in that room.



RoomMemberCount(RoomMemberCountConditionData)

Matches the current number of members in the room.



SenderNotificationPermission(SenderNotificationPermissionConditionData)

Takes into account the current power levels in the room, ensuring the sender of the event has high enough power to trigger the notification.



RoomVersionSupports(RoomVersionSupportsConditionData)

Available on crate feature unstable-msc3931 only.

Apply the rule only to rooms that support a given feature.



EventPropertyIs(EventPropertyIsConditionData)

Exact value match on a property of the event.



EventPropertyContains(EventPropertyContainsConditionData)

Exact value match on a value in an array property of the event.



ThreadSubscription(ThreadSubscriptionConditionData)

Available on crate feature unstable-msc4306 only.

Matches a thread event based on the user’s thread subscription status, as defined by MSC4306.

Implementations

Source

impl PushCondition

pub fn kind(&self) -> &str

The value of the kind field for this condition.

pub fn custom_data(&self) -> Option<&JsonObject>

The data, if this is a custom condition.

pub async fn applies( &self, event: &FlattenedJson, context: &PushConditionRoomCtx, ) -> bool

Check if this condition applies to the event.

Arguments
  • event - The flattened JSON representation of a room message event.
  • context - The context of the room at the time of the event. If the power levels context is missing from it, conditions that depend on it will never apply.

Returns false if this condition is unsupported.