Tweak

Enum Tweak 

#[non_exhaustive]
pub enum Tweak { Sound(SoundTweakValue), Highlight(HighlightTweakValue), }
The set_tweak action.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Sound(SoundTweakValue)

The sound to be played when this notification arrives.

A device may choose to alert the user by some other means if appropriate, eg. vibration.



Highlight(HighlightTweakValue)

A boolean representing whether or not this message should be highlighted in the UI.

Implementations

Source

impl Tweak

pub fn new(set_tweak: String, value: Option<Box<RawJsonValue>>) -> Result<Self>

Creates a new Tweak.

Prefer to use the public variants of Tweak where possible; this constructor is meant be used for unsupported tweaks only and does not allow setting arbitrary data for supported ones.

Errors

Returns an error if the set_tweak is known and deserialization of value to the corresponding variant fails.

pub fn set_tweak(&self) -> &str

Access the set_tweak value.

pub fn custom_value(&self) -> Option<&RawJsonValue>

Access the value, if it is a custom tweak.