#[non_exhaustive]pub struct SenderNotificationPermissionConditionData {
pub key: NotificationPowerLevelsKey,
}Expand description
Data for the sender_notification_permission PushCondition.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.key: NotificationPowerLevelsKeyThe field in the power level event the user needs a minimum power level for.
Fields must be specified under the notifications property in the power level event’s
content.
Implementations
Sourceimpl SenderNotificationPermissionConditionData
impl SenderNotificationPermissionConditionData
Sourcepub fn new(key: NotificationPowerLevelsKey) -> Self
pub fn new(key: NotificationPowerLevelsKey) -> Self
Construct a new EventMatchConditionData with the given field.